Welcome to Perry Bot's documentation!
======================================

.. attention::
    This is the documentation for the ``develop`` branch.

.. include:: readme.rst

=========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   contributing
   authors
   history
